@@ -148,8 +148,8 @@ def _directory_fixer(_dir):
 
 
 def install_client_package(test=False):
-    files = ['__init__.py', 'downloader.py', 'client.py',
-             'utils.py', 'patcher.py', 'version.py']
+    files = ['client.py', 'compat.py', 'config.py', 'downloader.py',
+             'patcher.py', 'utils.py', 'version.py']
     package_name = 'not_so_tuf'
     if test:
         dir_ = os.getcwd()
@@ -167,9 +167,12 @@ def install_client_package(test=False):
                 if os.path.exists(package_name):
                     shutil.rmtree(package_name)
                 os.mkdir(package_name)
-            with ChDir('not_so_tuf'):
+            with ChDir(package_name):
                 for f in files:
                     shutil.copy(f, package_dir)
+            with ChDir(package_dir):
+                with open('__init__.py', 'w') as f:
+                    f.write('# Nothing to see here')
 
         else:
             with ChDir(_cwd):
@@ -178,6 +181,9 @@ def install_client_package(test=False):
                 os.mkdir(package_name)
                 for f in files:
                     shutil.copy(os.path.join(dir_, f), package_name)
+                with ChDir(package_name):
+                    with open('__init__.py', 'w') as f:
+                        f.write('# Nothing to see here')
 
 
 def write_client_config(config_object, test=False):
