@@ -71,7 +71,7 @@ class Client(object):
         self.update_url = self._fix_update_url(config.get('UPDATE_URL'))
         self.app_name = config.get('APP_NAME')
         self.data_dir = config.get('APP_DATA_DIR', None)
-        self.public_key = config.get('PUBLIC_KEY')
+        self.public_key = config.get('PUBLIC_KEY', None)
         self.debug = config.get('DEBUG', False)
         self.version_file = 'version.json'
         self.version_url = self.update_url + self.version_file
@@ -90,6 +90,10 @@ class Client(object):
         self.plat = platform_
         if test is False:
             self._setup()
+        self._get_update_manifest()
+
+    def refresh(self):
+        self._get_update_manifest()
 
     def update_check(self, name, version):
         """Proxy method for :meth:`_patch_update` & :meth:`_full_update`.
@@ -109,25 +113,23 @@ class Client(object):
 
                 False - Update Failed
         """
-        self._load_json()
-        self._check_version_file_sig()
-
         self.name = name
         self.version = version
 
-        if FROZEN:
+        if FROZEN and self.name == self.app_name:
             self._install_base_binary()
             # Removes old versions of update being checked
-            self._remove_old_updates()
+        self._remove_old_updates()
 
         if not self.verified:
+            log.error('Version file not verified')
             return False
         log.info('Checking for {} updates...'.format(name))
         try:
             self.highest_version = self._get_highest_version(name)
         except Exception as e:
             log.error(str(e), exc_info=True)
-            log.warning('Supplied version number not '
+            log.warning('Supplied package name not '
                         'found -> {}'.format(version))
             return False
         if _version_string_to_tuple(self.highest_version) <= \
@@ -159,23 +161,20 @@ class Client(object):
             return False
 
     def install_restart(self):
-        """Proxy method for :meth:`_unzip_file`,
-        :meth:`_remove_version_number` & :meth:`_move_restart` Downloaded
-        updated will be unzipped, moved to the destination location and
-        restarted as updated application.
+        """Proxy method for :meth:`_unzip_file` & :meth:`_move_restart`
+        Downloaded updated will be unzipped, moved to the destination
+        location and restarted as updated application.
         """
         self._unzip_file()
-        self._remove_version_number()
         self._move_restart()
 
     def install(self):
-        """Proxy method for :meth:`_unzip_file` &
-        :meth:`_remove_version_number`.  Downloaded update will be unzipped
-        ready to be moved to destination and the application restarted. This
-        call should be followed by :meth:`restart` to complete update.
+        """Proxy method for :meth:`_unzip_file`. Downloaded update will
+        be unzipped ready to be moved to destination and the application
+        restarted. This call should be followed by :meth:`restart` to
+        complete update.
         """
         self._unzip_file()
-        self._remove_version_number()
 
     def restart(self):
         """Proxy method for :meth:`_move_restart`.  Will move update to
@@ -185,7 +184,7 @@ class Client(object):
 
     def _unzip_file(self):
         platform_name = self.name
-        if sys.platform == 'win32':
+        if sys.platform == 'win32' and self.name == self.app_name:
             platform_name += '.exe'
         filename = self._get_filename_with_extension(self.name,
                                                      self.highest_version)
@@ -199,14 +198,6 @@ class Client(object):
             # cmd = 'unzip "{}"'.format(filename)
             # os.system(cmd)
 
-    def _remove_version_number(self):
-        filename = self._get_filename_with_extension(self.name,
-                                                     self.highest_version)
-        with ChDir(self.update_folder):
-            self.fixed_filename = re.sub('-' + self.plat +
-                                         '-[0-9]+\.[0-9]+\.[0-9]+.*', '',
-                                         filename)
-
     def _move_restart(self):
         """Unix: Overwrites the running applications binary, then starts
         the updated binary in the currently running applications process
@@ -215,8 +206,9 @@ class Client(object):
         Windows: Moves update to current directory of running application
         then restarts application using new update."""
         _dir = os.path.dirname(sys.argv[0])
-        current_app = os.path.join(_dir, self.fixed_filename)
-        updated_app = os.path.join(self.update_folder, self.fixed_filename)
+
+        current_app = os.path.join(_dir, self.name)
+        updated_app = os.path.join(self.update_folder, self.name)
         if sys.platform != 'win32':
             shutil.move(updated_app, current_app)
             os.chmod(current_app, execute_permission)
@@ -259,9 +251,9 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
 
         """
         log.info('Starting patch update')
-
-        # Just checking to see if the latest update is available to patch
-        # If not we'll just do a full binary download
+        filename = self._get_filename_with_extension(name, version)
+        # Just checking to see if the zip for the current version is
+        # available to patch If not we'll just do a full binary download
         if not os.path.exists(os.path.join(self.update_folder, filename)):
             log.warning('{} got deleted. No base binary to start patching '
                         'form'.format(filename))
@@ -271,8 +263,7 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
                     self.update_folder)
 
         # Returns True if everything went well
-        result = p.start()
-        return result
+        return p.start()
 
     def _full_update(self, name, version):
         """Updates the binary by downloading full update
@@ -289,15 +280,16 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
 
                 False - Update Failed
         """
-        # Takes resource name and current installed version number
-        url = self._get_file_url(name, self.highest_version)
+
+        url = self._get_new_update_url(name)
         filename = self._get_filename_with_extension(name,
                                                      self.highest_version)
         log.info('Starting full update')
         with ChDir(self.update_folder):
-            # _hash = self.json_data['y_data'][name][version]['md5']
-            version_ = self.json_data['y_data'][name][self.highest_version]
-            _hash = version_[self.plat]['md5']
+            # Someone please tell me if this is the correct way
+            # to dig deep into this dict
+            v = self.json_data[self.updates_key][name][self.highest_version]
+            _hash = v[self.plat]['md5']
             log.info('Downloading update...')
             fd = FileDownloader(filename, url, _hash)
             result = fd.download_verify_write()
@@ -324,7 +316,6 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
         future patch updates
         """
         # ToDo: Get file extension dynamically
-        # ToDo: Add support for libraries
         # Depends on if support for more archive
         # formats are enabled.
         filename = '{}-{}-{}.zip'.format(self.name, platform_, __version__)
@@ -354,8 +345,16 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
                     log.debug('Removing old update: {}'.format(t))
                     os.remove(t)
 
-    def _check_version_file_sig(self):
-        """Verifies version file signature"""
+    def _get_update_manifest(self):
+        """Downloads & Verifies version file signature. On"""
+        log.debug('Loading version file...')
+        try:
+            v = urllib2.urlopen(self.version_url)
+            self.json_data = json.loads(v.read())
+        except Exception as e:
+            log.error(str(e))
+            self.json_data = None
+
         if self.json_data is None:
             log.warning('No json data loaded...')
             return
@@ -365,25 +364,28 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
             log.debug('Deleting sig from update data')
             del self.json_data['sig']
             update_data = json.dumps(self.json_data, sort_keys=True)
-            result = rsa_verify(update_data, self.sig, self.public_key)
+            try:
+                result = rsa_verify(update_data, self.sig, self.public_key)
+            except Exception as e:
+                log.error(str(e))
+                result = False
             if result:
                 log.debug('Version file verified')
                 self.verified = True
+                # ToDo: Remove once Stable.  All version files
+                #       Should be updated to using "updates" instead
+                #       of "y_data"
+                try:
+                    updates_key = self.json_data['updates']
+                    self.updates_key = 'updates'
+                except KeyError:
+                    self.updates_key = 'y_data'
             else:
+                self.json_data = None
                 log.warning('Version file sig mismatch')
         else:
             log.error('No sig in version file')
 
-    def _load_json(self):
-        """Downloads version file and converts to dict"""
-        log.debug('Loading version file...')
-        try:
-            v = urllib2.urlopen(self.version_url)
-            self.json_data = json.loads(v.read())
-        except Exception as e:
-            log.error(str(e))
-            self.json_data = None
-
     def _get_highest_version(self, name):
         """Parses version file and returns the highest version number.
 
@@ -394,14 +396,11 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
             (str) Highest version number
 
         """
-        highest_version = _version_tuple_to_string(sorted(map(
-                                                   _version_string_to_tuple,
-                                                   self.json_data['y_data']
-                                                   [name].keys()))[-1])
-        log.debug('Highest version: {}'.format(highest_version))
-        return highest_version
+        version = self.json_data['latest'][name]
+        log.debug('Highest version: {}'.format(version))
+        return version
 
-    def _get_file_url(self, name, version):
+    def _get_new_update_url(self, name):
         """Returns url for given name & version combo
 
         Args:
@@ -412,7 +411,8 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
         Returns:
             (str) Url
         """
-        url = self.json_data['y_data'][name][version][self.plat]['url']
+        latest = self.json_data['latest'][name]
+        url = self.json_data[self.updates_key][name][latest][self.plat]['url']
         log.debug('Update url: {}'.format(url))
         return url
 
@@ -428,9 +428,12 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
             (str) Filename with extension
         """
         # Parses version file and returns filename
-        version_plat = self.json_data['y_data'][name][version][self.plat]
-        # Used fro pep 8 compliance
-        filename = version_plat['filename']
+        try:
+            v_plat = self.json_data['updates'][name][version][self.plat]
+        except KeyError:
+            v_plat = self.json_data['y_data'][name][version][self.plat]
+        # Used for pep 8 compliance
+        filename = v_plat['filename']
         log.debug("Filename: {}".format(filename))
         return filename
 
