@@ -26,17 +26,19 @@ import logging
 import os
 import shutil
 
-try:
-    import rsa
-except ImportError:
-    rsa = None
+import Crypto
+import Crypto.Signature.PKCS1_v1_5
+import Crypto.Hash.SHA256
 
+from not_so_tuf.compat import is_py3
 from not_so_tuf.exceptions import KeyHandlerError
 from not_so_tuf.filecrypt import FileCrypt
 
-if rsa is None:
-    KeyHandlerError('You must have rsa installed.',
+if Crypto is None:
+    KeyHandlerError('You must have PyCrypto installed.',
                     expected=True)
+if is_py3:
+    long = int
 
 log = logging.getLogger(__name__)
 
@@ -96,13 +98,16 @@ class KeyHandler(object):
         # Makes a set of private and public keys
         # Used for authentication
         log.info('Making keys')
-        (pubkey, privkey) = rsa.newkeys(int(self.key_length))
+        rsa_key_object = Crypto.PublicKey.RSA.generate(int(self.key_length))
         # This is the private key, keep this secret. You'll need
         # it to sign new updates.
-        self.privkey = privkey.save_pkcs1()
+
+        self.privkey = rsa_key_object.exportKey(format='PEM')
+
+        public_key_object = rsa_key_object.publickey()
         # This is the public key you must distribute with your
         # program and pass to rsa_verify.
-        self.pubkey = (pubkey.n, pubkey.e)
+        self.pubkey = (public_key_object.n, public_key_object.e)
         self._write_keys_to_file(overwrite, test)
 
     def _write_keys_to_file(self, overwrite=False, test=False):
@@ -130,7 +135,7 @@ class KeyHandler(object):
         with open(public, 'w') as pub:
             pub.write(str(self.pubkey))
 
-    def sign_update(self):
+    def sign_update(self, test=False):
         """Proxy method for :meth:`_load_private_key`, :meth:`_add_sig` &
         :meth:`_write_update_data`
         """
@@ -138,7 +143,7 @@ class KeyHandler(object):
         # Loads version file to memory
         # Signs Version file
         # Writes version file back to disk
-        self._load_private_key()
+        self._load_private_key(test)
         self._add_sig()
         self._write_update_data()
 
@@ -156,13 +161,32 @@ class KeyHandler(object):
         # Searches keys folder for private key to sign version file
         path = os.path.join(self.keys_dir, self.private_key_name)
         log.debug('private key path: {}'.format(path))
-        if os.path.exists(path + '.enc'):
+        if os.path.exists(path + '.enc') or os.path.exists(path):
             log.debug('Found private key')
             return True
         log.debug("Didn't find private key")
         return False
 
-    def _load_private_key(self):
+    def _find_public_key(self):
+        """Checks for public key
+
+        Returns:
+            (bool) Meanings::
+
+                True - Private key found
+
+                False - Private key not found
+        """
+
+        path = os.path.join(self.keys_dir, self.public_key_name)
+        log.debug('Private key path: {}'.format(path))
+        if os.path.exists(path):
+            log.debug('Found public key')
+            return True
+        log.debug("Didn't find public key")
+        return False
+
+    def _load_private_key(self, test):
         """Loads private key to memory
 
         Raises:
@@ -174,16 +198,32 @@ class KeyHandler(object):
             raise KeyHandlerError(u"You don't have any keys",
                                   expected=True)
         privkey = os.path.join(self.keys_dir, self.private_key_name)
-        while 1:
-            try:
-                fc = FileCrypt(privkey)
-                fc.decrypt()
-                with open(privkey) as pk:
-                    self.privkey = rsa.PrivateKey.load_pkcs1(pk.read())
-                fc.encrypt()
-                break
-            except ValueError:
-                raw_input('Wrong password... Press enter to try again')
+        if test:
+            with open(privkey) as pk:
+                self.privkey = Crypto.PublicKey.RSA.importKey(pk.read())
+            return
+
+        fc = FileCrypt(privkey)
+        fc.decrypt()
+        with open(privkey) as pk:
+            self.privkey = Crypto.PublicKey.RSA.importKey(pk.read())
+        fc.encrypt()
+
+    def get_public_key(self):
+        if not self._find_public_key:
+            raise KeyHandlerError(u'You do not have a public key',
+                                  expected=True)
+        public_key = os.path.join(self.keys_dir, self.public_key_name)
+        with open(public_key) as f:
+            pub_key_data = f.read()
+        return KeyHandler._pub_key_string_to_tuple(pub_key_data)
+
+    @staticmethod
+    def _pub_key_string_to_tuple(x):
+        x = x.replace('(', '')
+        x = x.replace(')', '')
+        x = x.split(',')
+        return (long(x[0]), long(x[1]))
 
     def _load_update_data(self):
         """Loads version file
@@ -222,11 +262,12 @@ class KeyHandler(object):
             log.info('Deleting sig')
             del update_data['sig']
         _data = json.dumps(update_data, sort_keys=True)
-        signature = hexlify(rsa.pkcs1.sign(_data,
-                            self.privkey, 'SHA-256'))
+        _data_hash = Crypto.Hash.SHA256.new(_data)
+        signer = Crypto.Signature.PKCS1_v1_5.new(self.privkey)
+        signature = signer.sign(_data_hash)
 
         update_data = json.loads(_data)
-        update_data['sig'] = signature
+        update_data['sig'] = hexlify(signature)
         log.info('Adding sig to update data')
         self.update_data = update_data
 
@@ -240,16 +281,18 @@ class KeyHandler(object):
         log.info('Wrote version data')
         if self.update_data:
             with open(self.version_file, 'w') as f:
-                f.write(json.dumps(self.update_data, indent=4,
+                f.write(json.dumps(self.update_data, indent=2,
                         sort_keys=True))
         else:
             msg = u'You must sign update data first'
             raise KeyHandlerError(msg, expected=True)
 
-    def copy_decrypted_private_key(self):
+    def copy_decrypted_private_key(self, fc=None):
+        if fc is None:
+            fc = FileCrypt()
         privkey = os.path.join(self.keys_dir, self.private_key_name)
         log.debug('Private Key Path: {}'.format(privkey))
-        fc = FileCrypt(privkey)
+        fc.new_file(privkey)
         fc.decrypt()
         shutil.copy(privkey, privkey + ' copy')
         fc.encrypt()
