@@ -36,7 +36,8 @@ from not_so_tuf.exceptions import PackageHandlerError
 from not_so_tuf.utils import (ChDir, ask_yes_no, _get_package_hashes,
                               _remove_hidden_stuff_mac,
                               _version_string_to_tuple,
-                              _version_tuple_to_string)
+                              _version_tuple_to_string,
+                              FROZEN)
 
 
 log = logging.getLogger(__name__)
@@ -198,16 +199,16 @@ class PackageHandler(object):
                 log.info('Loading version file...')
                 self.json_data = json.loads(f.read())
                 log.debug('Found version file, now reading')
-                y_data = self.json_data.get('y_data', None)
+                updates = self.json_data.get('updates', None)
                 log.debug('Checking for valid data in version file...')
-                if y_data is None:
+                if updates is None:
                     log.debug('Invalid data in version file...')
-                    self.json_data = {'y_data': {}}
+                    self.json_data['updates'] = {}
                     log.debug('Created new version data')
         except Exception as e:
             log.error('Version file not found')
             log.error(e)
-            self.json_data = {'y_data': {}}
+            self.json_data = {'updates': {}}
             log.debug('Created new version file')
         log.info('Loaded version file')
 
@@ -229,7 +230,7 @@ class PackageHandler(object):
 
         """
         log.debug('Getting highest version number')
-        return sorted(self.json_data['y_data'][package_name].keys())[-1]
+        return sorted(self.json_data['updates'][package_name].keys())[-1]
 
     def _update_file_list(self, package_name):
         """Checks version file for package_name.  If not present adds to
@@ -239,7 +240,7 @@ class PackageHandler(object):
             package_name (str): Name of package to check against version file
         """
         log.info('Checking file list for {}'.format(package_name))
-        files = self.json_data['y_data']
+        files = self.json_data['updates']
         latest = self.json_data.get('latest', None)
         package_name = self._remove_ext(self._remove_version_number(
                                         package_name))
@@ -247,7 +248,7 @@ class PackageHandler(object):
         file_name = files.get(package_name, None)
         if file_name is None:
             log.info('Adding {} to file list'.format(package_name))
-            self.json_data['y_data'][package_name] = {}
+            self.json_data['updates'][package_name] = {}
 
         if latest is None:
             self.json_data['latest'] = {package_name: ''}
@@ -274,18 +275,35 @@ class PackageHandler(object):
                 info['patch_md5'] = patch_hash
                 info['patch_url'] = self.update_url + patch_name
 
-            log.debug('json version {}'.format(self.json_data['y_data']
+            log.debug('json version {}'.format(self.json_data['updates']
                       [name].get(version, None)))
-            if self.json_data['y_data'][name].get(version, None) is None:
+            if self.json_data['updates'][name].get(version, None) is None:
                 log.debug('Adding new version to file')
-                self.json_data['y_data'][name][version] = {}
-                if self.json_data['y_data'][name][version].get('platform',
-                                                               None) is None:
-                    name_ = self.json_data['y_data'][name]
+
+                # ToDo: Remove once stable.  Here to help with
+                #       transition to new version file format
+                versions = self.json_data['updates'][name]
+                # Preforming check for y_data because this could be a new
+                # version file not requiring legacy support :)
+                if len(versions) <= 8 and \
+                        self.json_data.get('y_data', None) is not None:
+                    self.json_data['y_data'][name][version] = {}
+                    temp = self.json_data['y_data'][name]
+                    temp[version][p['platform']] = info
+
+                self.json_data['updates'][name][version] = {}
+                if self.json_data['updates'][name][version].get('platform',
+                                                                None) is None:
+                    name_ = self.json_data['updates'][name]
                     name_[version][p['platform']] = info
+
             else:
+                if len(versions) <= 8 and \
+                        self.json_data.get('y_data', None) is not None:
+                    y_temp = self.json_data['y_data'][name]
+                    y_temp[version][p['platform']] = info
                 log.debug('Appending info data to version file')
-                self.json_data['y_data'][name][version][p['platform']] = info
+                self.json_data['updates'][name][version][p['platform']] = info
 
             self.json_data['latest'][name] = version
 
@@ -330,9 +348,15 @@ class PackageHandler(object):
 
                     patch_manifest.append(patch_info)
 
-            cpu_count = multiprocessing.cpu_count() * 2
-            pool = multiprocessing.Pool(processes=cpu_count)
-            pool_output = pool.map(_make_patch, patch_manifest)
+            if FROZEN and sys.platform == 'win32':
+                pool_output = []
+                for p in patch_manifest:
+                    patch_output = _make_patch(p)
+                    pool_output.append(patch_output)
+            else:
+                cpu_count = multiprocessing.cpu_count() * 2
+                pool = multiprocessing.Pool(processes=cpu_count)
+                pool_output = pool.map(_make_patch, patch_manifest)
 
             for i in pool_output:
                 for s in self.package_manifest:
