@@ -149,9 +149,27 @@ class Patcher(object):
                 False - Failed to find all patches
         """
         needed_patches = []
-        versions = sorted(map(_version_string_to_tuple,
-                          self.json_data['y_data'][name].keys()))
+        versions = []
+        # ToDo: Remove once framework is stable.  All clients should
+        #       Be updated to using updates instead of y_data
+        try:
+            y_versions = map(_version_string_to_tuple,
+                             self.json_data['y_data'][name].keys())
+            versions.extend(y_versions)
+        except KeyError:
+            log.debug('No updates found in y_data dict')
 
+        try:
+            u_versions = map(_version_string_to_tuple,
+                             self.json_data['updates'][name].keys())
+            versions.extend(u_versions)
+        except KeyError:
+            log.debug('No updates found in updates dict')
+
+        # Sorted here because i may forget to leave it when i delete
+        # the list/set down below.
+        # How i envisioned it: sorted(list(set(needed_patches)))
+        versions = sorted(versions)
         log.info('getting required patches')
         for i in versions:
             if i > _version_string_to_tuple(self.current_version):
@@ -162,16 +180,28 @@ class Patcher(object):
         # and start full binary update.
         log.info('Getting patch meta-data')
 
+        # ToDo: Remove once stable
+        #       Used to remove duplicate entries of updates.
+        #       Duplicates were introduced during version file
+        #       creation to help with transition to new version
+        #       file format.
+        needed_patches = list(set(needed_patches))
+
         for p in needed_patches:
             info = {}
             v_num = _version_tuple_to_string(p)
+            # ToDo: Remove this nasty/ugly try/except block!
+            #       Used for backwards compatibility.
+            #       Will remove once stable.
             try:
-                temp_name = self.json_data['y_data'][name][v_num][self.plat]
-                info['patch_name'] = temp_name['patch_name']
-                temp_url = self.json_data['y_data'][name][v_num][self.plat]
-                info['patch_url'] = temp_url['patch_url']
-                temp_hash = self.json_data['y_data'][name][v_num][self.plat]
-                info['patch_md5'] = temp_hash['patch_md5']
+                plat_info = self.json_data['updates'][name][v_num][self.plat]
+            except KeyError:
+                plat_info = self.json_data['y_data'][name][v_num][self.plat]
+
+            try:
+                info['patch_name'] = plat_info['patch_name']
+                info['patch_url'] = plat_info['patch_url']
+                info['patch_md5'] = plat_info['patch_md5']
                 self.patch_data.append(info)
             except KeyError:
                 log.error('Missing required patch meta-data')
@@ -211,7 +241,12 @@ class Patcher(object):
     def _write_update_to_disk(self):
         """Writes updated binary to disk"""
         log.info('Writing update to disk')
-        temp_filename = self.json_data['y_data'][self.name]
+        # ToDo: Remove try/except block once stable
+        #       Only keeping for compatibility reasons
+        try:
+            temp_filename = self.json_data['updates'][self.name]
+        except KeyError:
+            temp_filename = self.json_data['y_data'][self.name]
         filename = temp_filename[self.highest_version][self.plat]['filename']
         with ChDir(self.update_folder):
             with open(filename, 'wb') as f:
@@ -231,10 +266,15 @@ class Patcher(object):
                 hash = dict['hash']
         """
         info = {}
-        temp_filename = self.json_data['y_data'][name][version][self.plat]
-        info['filename'] = temp_filename['filename']
-        temp_hash = self.json_data['y_data'][name][version][self.plat]
-        info['hash'] = temp_hash['md5']
+        # ToDo: Remove try/except block once stable
+        #       Only kept around for compatibility reasons
+        try:
+            plat_info = self.json_data['updates'][name][version][self.plat]
+        except KeyError:
+            plat_info = self.json_data['y_data'][name][version][self.plat]
+
+        info['filename'] = plat_info['filename']
+        info['hash'] = plat_info['md5']
         return info
 
     def _get_package_hashes(self, package):
